@@ -1,4 +1,4 @@
-#! /usr/bin/python
+#! /usr/bin/python3
 # Written by Dan Mandle http://dan.mandle.me September 2012
 # http://www.danmandle.com/blog/getting-gpsd-to-work-with-python/
 # License: GPL 2.0
@@ -12,11 +12,13 @@
 
 from __future__ import absolute_import, print_function, division
 
-import gps
 import os
 import threading
 import time
 
+# PEP8, local imports go last.
+import gps
+
 gpsd = None          # setting the global variable
 
 os.system('clear')   # clear the terminal (optional)
@@ -35,7 +37,6 @@ class GpsPoller(threading.Thread):
 
     def run(self):
         """Run."""
-        global gpsd
         while gpsp.running:
             # this will continue to loop and grab EACH set of
             # gpsd info to clear the buffer
