@@ -3,13 +3,13 @@
  * SPDX-License-Identifier: BSD-2-clause
  */
 
-#include "../include/gpsd_config.h"  /* must be before all includes */
+#include "../include/gpsd_config.h"  // must be before all includes
 
 #include <stdbool.h>
 #include <stdio.h>
 #include "../include/gpsd.h"
 
-#if defined(ONCORE_ENABLE) && defined(BINARY_ENABLE)
+#if defined(ONCORE_ENABLE)
 #include "../include/bits.h"
 #include "../include/timespec.h"
 
@@ -18,7 +18,7 @@ static char enableBb[] = { 'B', 'b', 1 };
 static char getfirmware[] = { 'C', 'j' };
 /*static char enableEn[] =
     { 'E', 'n', 1, 0, 100, 100, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };*/
-/*static char enableAt2[]       = { 'A', 't', 2, };*/
+// static char enableAt2[]       = { 'A', 't', 2, };*/
 static unsigned char pollAs[] =
     { 'A', 's', 0x7f, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0x7f, 0xff,
     0xff, 0xff, 0xff
@@ -172,11 +172,12 @@ oncore_msg_navsol(struct gps_device_t *session, unsigned char *buf,
     float speed, track, dop;
     unsigned int i, j, st, nsv;
     int Bbused;
-    struct tm unpacked_date;
+    struct tm unpacked_date = {0};
     char ts_buf[TIMESPEC_LEN];
 
-    if (data_len != 76)
+    if (76 != data_len) {
         return 0;
+    }
 
     mask = ONLINE_SET;
     GPSD_LOG(LOG_DATA, &session->context->errout,
@@ -185,10 +186,10 @@ oncore_msg_navsol(struct gps_device_t *session, unsigned char *buf,
     flags = (unsigned char)getub(buf, 72);
 
     if (flags & 0x20) {
-        session->newdata.status = STATUS_FIX;
+        session->newdata.status = STATUS_GPS;
         session->newdata.mode = MODE_3D;
     } else if (flags & 0x10) {
-        session->newdata.status = STATUS_FIX;
+        session->newdata.status = STATUS_GPS;
         session->newdata.mode = MODE_2D;
     } else if ((flags & 0x08) &&
                session->driver.oncore.pos_hold_mode ==
@@ -205,7 +206,7 @@ oncore_msg_navsol(struct gps_device_t *session, unsigned char *buf,
         GPSD_LOG(LOG_WARN, &session->context->errout,
                  "oncore NAVSOL no fix - flags 0x%02x\n", flags);
         session->newdata.mode = MODE_NO_FIX;
-        session->newdata.status = STATUS_NO_FIX;
+        session->newdata.status = STATUS_UNK;
     }
     mask |= MODE_SET | STATUS_SET;
 
@@ -255,12 +256,12 @@ oncore_msg_navsol(struct gps_device_t *session, unsigned char *buf,
         mask |= LATLON_SET | SPEED_SET | TRACK_SET;
     }
     if (MODE_3D <= session->newdata.mode) {
-        session->newdata.altHAE = alt;  /* is WGS84 */
+        session->newdata.altHAE = alt;  // is WGS84
         mask |= ALTITUDE_SET;
     }
 
     gpsd_zero_satellites(&session->gpsdata);
-    /* Merge the satellite information from the Bb message. */
+    // Merge the satellite information from the Bb message.
     Bbused = 0;
     nsv = 0;
     for (i = st = 0; i < 8; i++) {
@@ -279,7 +280,7 @@ oncore_msg_navsol(struct gps_device_t *session, unsigned char *buf,
         if (sn) {
             session->gpsdata.skyview[st].PRN = (short)sv;
             session->gpsdata.skyview[st].ss = (double)sn;
-            for (j = 0; (int)j < session->driver.oncore.visible; j++)
+            for (j = 0; (int)j < session->driver.oncore.visible; j++) {
                 if (session->driver.oncore.PRN[j] == sv) {
                     session->gpsdata.skyview[st].elevation =
                         (double)session->driver.oncore.elevation[j];
@@ -288,15 +289,17 @@ oncore_msg_navsol(struct gps_device_t *session, unsigned char *buf,
                     Bbused |= 1 << j;
                     break;
                 }
-            /* bit 7 of the status word: sat used for position */
+            }
+            // bit 7 of the status word: sat used for position
             session->gpsdata.skyview[st].used = false;
             if (status & 0x80) {
                 session->gpsdata.skyview[st].used = true;
                 nsv++;
             }
-            /* bit 2 of the status word: using for time solution */
-            if (status & 0x02)
+            // bit 2 of the status word: using for time solution
+            if (status & 0x02) {
                 mask |= NTPTIME_IS | GOODTIME_IS;
+            }
             /*
              * The GOODTIME_IS mask bit exists distinctly from TIME_SET exactly
              * so an OnCore running in time-service mode (and other GPS clocks)
@@ -354,18 +357,20 @@ oncore_msg_utc_offset(struct gps_device_t *session, unsigned char *buf,
 {
     int utc_offset;
 
-    if (data_len != 8)
+    if (8 != data_len) {
         return 0;
+    }
 
     utc_offset = (int)getub(buf, 4);
     GPSD_LOG(LOG_DATA, &session->context->errout,
              "oncore UTCTIME - leap seconds: %d\n", utc_offset);
-    if (utc_offset == 0)
-        return 0;               /* that part of almanac not received yet */
+    if (0 == utc_offset) {
+        return 0;               // that part of almanac not received yet
+    }
 
     session->context->leap_seconds = utc_offset;
     session->context->valid |= LEAP_SECOND_VALID;
-    return 0;                   /* no flag for leap seconds update */
+    return 0;                   // no flag for leap seconds update
 }
 
 /**
@@ -381,14 +386,15 @@ oncore_msg_pos_hold_mode(struct gps_device_t *session, unsigned char *buf,
 {
     int pos_hold_mode;
 
-    if (data_len != 8)
+    if (8 != data_len) {
         return 0;
+    }
 
     pos_hold_mode = (int)getub(buf, 4);
     GPSD_LOG(LOG_DATA, &session->context->errout,
              "oncore pos hold mode: %d\n", pos_hold_mode);
 
-    /* Add 1 to distinguish an unknown (not set) value from mode off. */
+    // Add 1 to distinguish an unknown (not set) value from mode off.
     session->driver.oncore.pos_hold_mode = pos_hold_mode + 1;
     return 0;
 }
@@ -402,8 +408,9 @@ oncore_msg_pps_offset(struct gps_device_t *session, unsigned char *buf,
 {
     int pps_offset_ns;
 
-    if (data_len != 11)
+    if (11 != data_len) {
         return 0;
+    }
 
     pps_offset_ns = (int)getbes32(buf, 4);
     GPSD_LOG(LOG_DATA, &session->context->errout,
@@ -422,20 +429,22 @@ oncore_msg_svinfo(struct gps_device_t *session, unsigned char *buf,
 {
     unsigned int i, nchan;
 
-    if (data_len != 92)
+    if (92 != data_len) {
         return 0;
+    }
 
     GPSD_LOG(LOG_DATA, &session->context->errout,
              "oncore SVINFO - satellite data\n");
     nchan = (unsigned int)getub(buf, 4);
     GPSD_LOG(LOG_DATA, &session->context->errout,
              "oncore SVINFO - %d satellites:\n", nchan);
-    /* Then we clamp the value to not read outside the table. */
-    if (nchan > 12)
+    // Then we clamp the value to not read outside the table.
+    if (12 < nchan) {
         nchan = 12;
+    }
     session->driver.oncore.visible = (int)nchan;
     for (i = 0; i < nchan; i++) {
-        /* get info for one channel/satellite */
+        // get info for one channel/satellite
         unsigned int off = 5 + 7 * i;
 
         int sv = (int)getub(buf, off);
@@ -445,7 +454,7 @@ oncore_msg_svinfo(struct gps_device_t *session, unsigned char *buf,
         GPSD_LOG(LOG_DATA, &session->context->errout,
                  "%2d %2d %2d %3d\n", i, sv, el, az);
 
-        /* Store for use when Ea messages come. */
+        // Store for use when Ea messages come.
         session->driver.oncore.PRN[i] = sv;
         session->driver.oncore.elevation[i] = (short)el;
         session->driver.oncore.azimuth[i] = (short)az;
@@ -461,14 +470,15 @@ oncore_msg_svinfo(struct gps_device_t *session, unsigned char *buf,
  *
  *       m         - mode, 0=GPS, 1=UTC
  */
-static gps_mask_t
-oncore_msg_time_mode(struct gps_device_t *session UNUSED,
-                     unsigned char *buf UNUSED, size_t data_len UNUSED)
+static gps_mask_t oncore_msg_time_mode(struct gps_device_t *session UNUSED,
+                                       unsigned char *buf UNUSED,
+                                       size_t data_len UNUSED)
 {
     int time_mode;
 
-    if (data_len != 8)
+    if (8 != data_len) {
         return 0;
+    }
 
     time_mode = (int)getub(buf, 4);
     GPSD_LOG(LOG_DATA, &session->context->errout,
@@ -480,20 +490,21 @@ oncore_msg_time_mode(struct gps_device_t *session UNUSED,
 /**
  * GPS Time RAIM
  */
-static gps_mask_t
-oncore_msg_time_raim(struct gps_device_t *session UNUSED,
-                     unsigned char *buf UNUSED, size_t data_len UNUSED)
+static gps_mask_t oncore_msg_time_raim(struct gps_device_t *session UNUSED,
+                                       unsigned char *buf UNUSED,
+                                       size_t data_len UNUSED)
 {
     int sawtooth_ns;
 
-    if (data_len != 69)
+    if (69 != data_len) {
         return 0;
+    }
 
     sawtooth_ns = (int)getub(buf, 25);
     GPSD_LOG(LOG_DATA, &session->context->errout,
              "oncore PPS sawtooth: %d\n",sawtooth_ns);
 
-    /* session->driver.oncore.traim_sawtooth_ns = sawtooth_ns; */
+    // session->driver.oncore.traim_sawtooth_ns = sawtooth_ns;
 
     return 0;
 }
@@ -501,9 +512,9 @@ oncore_msg_time_raim(struct gps_device_t *session UNUSED,
 /**
  * GPS Firmware
  */
-static gps_mask_t
-oncore_msg_firmware(struct gps_device_t *session UNUSED,
-                    unsigned char *buf UNUSED, size_t data_len UNUSED)
+static gps_mask_t oncore_msg_firmware(struct gps_device_t *session UNUSED,
+                                      unsigned char *buf UNUSED,
+                                      size_t data_len UNUSED)
 {
     return 0;
 }
@@ -518,12 +529,13 @@ gps_mask_t oncore_dispatch(struct gps_device_t * session, unsigned char *buf,
 {
     unsigned int type;
 
-    if (len == 0)
+    if (0 == len) {
         return 0;
+    }
 
     type = ONCTYPE(buf[2], buf[3]);
 
-    /* we may need to dump the raw packet */
+    // we may need to dump the raw packet
     GPSD_LOG(LOG_RAW, &session->context->errout,
              "raw Oncore packet type 0x%04x\n", type);
 
@@ -541,7 +553,7 @@ gps_mask_t oncore_dispatch(struct gps_device_t * session, unsigned char *buf,
     case ONCTYPE('B', 'o'):
         return oncore_msg_utc_offset(session, buf, len);
     case ONCTYPE('A', 's'):
-        return 0;               /* position hold position */
+        return 0;               // position hold position
     case ONCTYPE('A', 't'):
         return oncore_msg_pos_hold_mode(session, buf, len);
     case ONCTYPE('A', 'w'):
@@ -550,7 +562,7 @@ gps_mask_t oncore_dispatch(struct gps_device_t * session, unsigned char *buf,
         return oncore_msg_pps_offset(session, buf, len);
 
     default:
-        /* FIX-ME: This gets noisy in a hurry. Change once your driver works */
+        // FIXME: This gets noisy in a hurry. Change once your driver works
         GPSD_LOG(LOG_WARN, &session->context->errout,
                  "unknown packet id @@%c%c length %zd\n",
                  type >> 8, type & 0xff, len);
@@ -592,30 +604,33 @@ static ssize_t oncore_control_send(struct gps_device_t *session,
 
 static void oncore_event_hook(struct gps_device_t *session, event_t event)
 {
-    if (session->context->readonly)
+    if (session->context->readonly) {
         return;
+    }
 
     /*
      * Some oncore VP variants that have not been used after long
      * power-down will be silent on startup.  Provoke
      * identification by requesting the firmware version.
      */
-    if (event == event_wakeup)
+    if (event == EVENT_WAKEUP) {
         (void)oncore_control_send(session, getfirmware, sizeof(getfirmware));
+    }
 
     if (session->context->passive) {
         return;
     }
     /*
-     * FIX-ME: It might not be necessary to call this on reactivate.
+     * FIXME: It might not be necessary to call this on reactivate.
      * Experiment to see if the holds its settings through a close.
      */
-    if (event == event_identified || event == event_reactivate) {
+    if (event == EVENT_IDENTIFIED ||
+        event == EVENT_REACTIVATE) {
         (void)oncore_control_send(session, enableEa, sizeof(enableEa));
         (void)oncore_control_send(session, enableBb, sizeof(enableBb));
-        /*(void)oncore_control_send(session, enableEn, sizeof(enableEn)); */
-        /*(void)oncore_control_send(session,enableAt2,sizeof(enableAt2)); */
-        /*(void)oncore_control_send(session,pollAs,sizeof(pollAs)); */
+        // (void)oncore_control_send(session, enableEn, sizeof(enableEn));
+        // (void)oncore_control_send(session,enableAt2,sizeof(enableAt2));
+        // (void)oncore_control_send(session,pollAs,sizeof(pollAs));
         (void)oncore_control_send(session, (char*)pollBo, sizeof(pollBo));
     }
 }
@@ -632,42 +647,41 @@ static double oncore_time_offset(struct gps_device_t *session UNUSED)
 
 static gps_mask_t oncore_parse_input(struct gps_device_t *session)
 {
-    if (session->lexer.type == ONCORE_PACKET) {
+    if (ONCORE_PACKET == session->lexer.type) {
         return oncore_dispatch(session, session->lexer.outbuffer,
                              session->lexer.outbuflen);
-#ifdef NMEA0183_ENABLE
-    } else if (session->lexer.type == NMEA_PACKET) {
+    }
+    if (NMEA_PACKET == session->lexer.type) {
         return nmea_parse((char *)session->lexer.outbuffer, session);
-#endif /* NMEA0183_ENABLE */
-    } else
-        return 0;
+    }
+    return 0;
 }
 
-/* This is everything we export */
-/* *INDENT-OFF* */
+// This is everything we export
+// *INDENT-OFF*
 const struct gps_type_t driver_oncore = {
 
-    .type_name        = "Motorola Oncore",      /* Full name of type */
-    .packet_type      = ONCORE_PACKET,          /* numeric packet type */
-    .flags            = DRIVER_STICKY,          /* remember this */
-    .trigger          = NULL,                   /* identifying response */
-    .channels         = 12,                     /* device channel count */
-    .probe_detect     = NULL,                   /* no probe */
-    .get_packet       = generic_get,            /* packet getter */
-    .parse_packet     = oncore_parse_input,     /* packet parser */
-    .rtcm_writer      = gpsd_write,             /* device accepts RTCM */
-    .init_query       = NULL,                   /* non-perturbing query */
-    .event_hook       = oncore_event_hook,      /* lifetime event hook */
-    .speed_switcher   = NULL,                   /* no speed setter */
-    .mode_switcher    = NULL,                   /* no mode setter */
-    .rate_switcher    = NULL,                   /* no speed setter */
-    .min_cycle.tv_sec  = 1,                     /* 1Hz */
+    .type_name        = "Motorola Oncore",      // Full name of type
+    .packet_type      = ONCORE_PACKET,          // numeric packet type
+    .flags            = DRIVER_STICKY,          // remember this
+    .trigger          = NULL,                   // identifying response
+    .channels         = 12,                     // device channel count
+    .probe_detect     = NULL,                   // no probe
+    .get_packet       = packet_get1,            // packet getter
+    .parse_packet     = oncore_parse_input,     // packet parser
+    .rtcm_writer      = gpsd_write,             // device accepts RTCM
+    .init_query       = NULL,                   // non-perturbing query
+    .event_hook       = oncore_event_hook,      // lifetime event hook
+    .speed_switcher   = NULL,                   // no speed setter
+    .mode_switcher    = NULL,                   // no mode setter
+    .rate_switcher    = NULL,                   // no speed setter
+    .min_cycle.tv_sec  = 1,                     // 1Hz
     .min_cycle.tv_nsec = 0,
-    /* Control string sender - should provide checksum and headers/trailer */
-    .control_send   = oncore_control_send,      /* to send control strings */
-    .time_offset = oncore_time_offset,          /* NTP offset array */
+    // Control string sender - should provide checksum and headers/trailer
+    .control_send   = oncore_control_send,      // to send control strings
+    .time_offset = oncore_time_offset,          // NTP offset array
 };
-/* *INDENT-ON* */
-#endif /* defined(ONCORE_ENABLE) && defined(BINARY_ENABLE) */
+// *INDENT-ON*
+#endif  // defined(ONCORE_ENABLE)
 
 // vim: set expandtab shiftwidth=4
