@@ -25,12 +25,20 @@
  * If using vi, ":%s/_PROTO_/MYDRIVER/g" and ":%s/_proto_/mydriver/g"
  * should produce a source file that comes very close to being useful.
  * You will also need to add hooks for your new driver to:
- * SConstruct
+ * SConscript
+ *   in: boolopts = (
+ *   in: libgpsd_sources = [
  * drivers.c
- * gpsd.h-tail
- * libgpsd_core.c
+ *   beneath: 'const struct gps_type_t driver_pps = {'
+ *   in: static const struct gps_type_t *gpsd_driver_array[] = {
+ * gpsd.h
+ *   in: struct gps_lexer_t {
+ * libgpsd_core.c ????
  * packet.c
+ *   in: static bool nextstate(struct gps_lexer_t *lexer, unsigned char c)
+ *   in: void packet_parse(struct gps_lexer_t *lexer)
  * packet_states.h
+ *  above: closing #endif
  *
  * This file is Copyright 2010 by the GPSD project
  * SPDX-License-Identifier: BSD-2-clause
@@ -42,7 +50,7 @@
 #include <stdbool.h>
 #include <string.h>
 
-#if defined(_PROTO__ENABLE) && defined(BINARY_ENABLE)
+#if defined(_PROTO__ENABLE)
 
 #include "../include/bits.h"
 
@@ -221,7 +229,7 @@ static gps_mask_t _proto__msg_svinfo(struct gps_device_t *session,
         if(session->gpsdata.PRN[i])
                 st++;
     }
-    /* if the satellite-info setence gives you UTC time, use it */
+    /* if the satellite-info sentence gives you UTC time, use it */
     session->gpsdata.skyview_time = NaN;
     session->gpsdata.satellites_used = nsv;
     session->gpsdata.satellites_visible = st;
@@ -374,7 +382,7 @@ static void _proto__event_hook(struct gps_device_t *session, event_t event)
     if (session->context->readonly)
         return;
 
-    if (event == event_wakeup) {
+    if (event == EVENT_WAKEUP) {
        /*
         * Code to make the device ready to communicate.  Only needed if the
         * device is in some kind of sleeping state, and only shipped to
@@ -382,7 +390,7 @@ static void _proto__event_hook(struct gps_device_t *session, event_t event)
         * that might not be GPSes at all.
         */
     }
-    if (event == event_identified) {
+    if (event == EVENT_IDENTIFIED) {
         /*
          * Fires when the first full packet is recognized from a
          * previously unidentified device.  The session.lexer counter
@@ -392,10 +400,10 @@ static void _proto__event_hook(struct gps_device_t *session, event_t event)
          * session->subtype.
          */
     }
-    if (event == event_configure) {
+    if (event == EVENT_CONFIGURE) {
         /*
          * Change sentence mix and set reporting modes as needed.
-         * Called immediately after event_identified fires, then just
+         * Called immediately after EVENT_IDENTIFIED fires, then just
          * after every packet received thereafter, but you probably
          * only want to take actions on the first few packets after
          * the session.lexer counter has been zeroed,
@@ -405,18 +413,18 @@ static void _proto__event_hook(struct gps_device_t *session, event_t event)
          * sends with the first few packet reads, which is useful for
          * devices with small receive buffers.
          */
-    } else if (event == event_driver_switch) {
+    } else if (event == EVENT_DRIVER_SWITCH) {
         /*
          * Fires when the driver on a device is changed *after* it
          * has been identified.
          */
-    } else if (event == event_deactivate) {
+    } else if (event == EVENT_DEACTIVATE) {
         /*
          * Fires when the device is deactivated.  Usr this to revert
-         * whatever was done at event_identify and event_configure
+         * whatever was done at EVENT_IDENTIFY and EVENT_CONFIGURE
          * time.
          */
-    } else if (event == event_reactivate) {
+    } else if (event == EVENT_REACTIVATE) {
        /*
         * Fires when a device is reactivated after having been closed.
         * Use this hook for re-establishing device settings that
@@ -432,15 +440,14 @@ static void _proto__event_hook(struct gps_device_t *session, event_t event)
  */
 static gps_mask_t _proto__parse_input(struct gps_device_t *session)
 {
-    if (session->lexer.type == _PROTO__PACKET) {
+    if (_PROTO__PACKET == session->lexer.type) {
         return _proto__dispatch(session, session->lexer.outbuffer,
                                 session->lexer.outbuflen);
-#ifdef NMEA0183_ENABLE
-    } else if (session->lexer.type == NMEA_PACKET) {
+    }
+    if (NMEA_PACKET == session->lexer.type) {
         return nmea_parse((char *)session->lexer.outbuffer, session);
-#endif /* NMEA0183_ENABLE */
-    } else
-        return 0;
+    }
+    return 0;
 }
 
 static bool _proto__set_speed(struct gps_device_t *session,
@@ -505,7 +512,7 @@ const struct gps_type_t driver__proto__binary = {
     .type_name        = "_proto",
     /* Associated lexer packet type */
     .packet_type      = _PROTO__PACKET,
-    /* Driver tyoe flags */
+    /* Driver type flags */
     .flags            = DRIVER_NOFLAGS,
     /* Response string that identifies device (not active) */
     .trigger          = NULL,
@@ -514,7 +521,7 @@ const struct gps_type_t driver__proto__binary = {
     /* Startup-time device detector */
     .probe_detect     = _proto__probe_detect,
     /* Packet getter (using default routine) */
-    .get_packet       = generic_get,
+    .get_packet       = packet_get1,
     /* Parse message packets */
     .parse_packet     = _proto__parse_input,
     /* RTCM handler (using default routine) */
@@ -536,6 +543,6 @@ const struct gps_type_t driver__proto__binary = {
     .time_offset     = _proto_time_offset,
 /* *INDENT-ON* */
 };
-#endif /* defined(_PROTO__ENABLE) && defined(BINARY_ENABLE) */
+#endif  // defined(_PROTO__ENABLE)
 
 // vim: set expandtab shiftwidth=4
