@@ -12,6 +12,7 @@
 from __future__ import absolute_import, print_function, division
 
 import json
+import os
 import select
 import socket
 import sys
@@ -60,7 +61,8 @@ class gpscommon(object):
             # file input, binary mode, for binary data.
             self.input_fd = open(input_file_name, "rb")
 
-        elif host is not None and port is not None:
+        elif ((host is not None and
+               port is not None)):
             self.host = host
             self.port = port
             self.connect(self.host, self.port)
@@ -73,30 +75,31 @@ class gpscommon(object):
         there is no port specified, that suffix will be stripped off and the
         number interpreted as the port number to use.
         """
-        if not port and (host.find(':') == host.rfind(':')):
+        if ((not port and
+             (host.find(':') == host.rfind(':')))):
             i = host.rfind(':')
-            if i >= 0:
+            if 0 <= i:
                 host, port = host[:i], host[i + 1:]
             try:
                 port = int(port)
             except ValueError:
                 raise socket.error("nonnumeric port")
-        # if self.verbose > 0:
+        # if 0 < self.verbose:
         #    print 'connect:', (host, port)
         self.sock = None
         for res in socket.getaddrinfo(host, port, 0, socket.SOCK_STREAM):
             af, socktype, proto, _canonname, sa = res
             try:
                 self.sock = socket.socket(af, socktype, proto)
-                # if self.debuglevel > 0: print 'connect:', (host, port)
+                # if 0 < self.debuglevel: print 'connect:', (host, port)
                 self.sock.connect(sa)
-                if self.verbose > 0:
+                if 0 < self.verbose:
                     print('connected to tcp://{}:{}'.format(host, port))
                 break
             # do not use except ConnectionRefusedError
             # # Python 2.7 doc does have this exception
             except socket.error as e:
-                if self.verbose > 1:
+                if 1 < self.verbose:
                     msg = str(e) + ' (to {}:{})'.format(host, port)
                     sys.stderr.write("error: {}\n".format(msg.strip()))
                 self.close()
@@ -117,7 +120,8 @@ class gpscommon(object):
 
     def waiting(self, timeout=0):
         """Return True if data is ready for the client."""
-        if self.linebuffer or self.input_fd:
+        if ((self.linebuffer or
+             self.input_fd)):
             # check for input_fd EOF?
             return True
         if self.sock is None:
@@ -125,11 +129,12 @@ class gpscommon(object):
 
         (winput, _woutput, _wexceptions) = select.select(
             (self.sock,), (), (), timeout)
-        return winput != []
+        return [] != winput
 
     def read(self):
         """Wait for and read data being streamed from the daemon."""
-        if not self.input_fd and None is self.sock:
+        if ((not self.input_fd and
+             None is self.sock)):
             # input_fd.open() was earlier, and read_only, so no stream()
             self.connect(self.host, self.port)
             if None is self.sock:
@@ -137,31 +142,32 @@ class gpscommon(object):
             self.stream()
 
         eol = self.linebuffer.find(b'\n')
-        if eol == -1:
+        if -1 == eol:
             # RTCM3 JSON can be over 4.4k long, so go big
             if self.input_fd:
                 frag = self.input_fd.read(8192)
             else:
                 frag = self.sock.recv(8192)
 
-            self.linebuffer += frag
-            if not self.linebuffer:
-                if self.verbose > 1:
+            if not frag:
+                if 1 < self.verbose:
                     sys.stderr.write(
                         "poll: no available data: returning -1.\n")
                 # Read failed
                 return -1
 
+            self.linebuffer += frag
+
             eol = self.linebuffer.find(b'\n')
-            if eol == -1:
-                if self.verbose > 1:
+            if -1 == eol:
+                if 1 < self.verbose:
                     sys.stderr.write("poll: partial message: returning 0.\n")
                 # Read succeeded, but only got a fragment
                 self.response = ''  # Don't duplicate last response
-                self.bresponse = ''  # Don't duplicate last response
+                self.bresponse = b''  # Don't duplicate last response
                 return 0
         else:
-            if self.verbose > 1:
+            if 1 < self.verbose:
                 sys.stderr.write("poll: fetching from buffer.\n")
 
         # We got a line
@@ -218,12 +224,12 @@ class gpsjson(object):
 
     """Basic JSON decoding."""
 
-    def __init__(self):
+    def __init__(self, verbose=0):
         """Init gpsjson."""
         self.data = None
         self.stream_command = None
         self.enqueued = None
-        self.verbose = -1
+        self.verbose = verbose
 
     def __iter__(self):
         """Broken __iter__."""
@@ -251,7 +257,7 @@ class gpsjson(object):
             self.stream_command = self.enqueued
 
         if self.stream_command:
-            if self.verbose > 1:
+            if 1 < self.verbose:
                 sys.stderr.write("send: stream as:"
                                  " {}\n".format(self.stream_command))
             self.send(self.stream_command)
@@ -370,9 +376,46 @@ class dictwrapper(object):
         """length of dictwrapper."""
         return len(self.__dict__)
 
-#
-# Someday a cleaner Python interface using this machinery will live here
-#
+
+class baton(object):
+    """Ship progress indication to stderr."""
+
+    def __init__(self, prompt, endmsg=None):
+        """Init class baton."""
+        self.stream = sys.stderr
+        self.tty = os.isatty(self.stream.fileno())
+        self.stream.flush()
+        self.count = 0
+        self.endmsg = endmsg
+        self.time = time.time()
+        self.tick = int(self.time)
+        self.stream.write(prompt + "...")
+        if self.tty:
+            self.stream.write(" \b")
+        self.stream.flush()
+
+    def twirl(self, ch=None):
+        """Twirl the baton."""
+        if ((self.stream is None or
+             not self.tty)):
+            return
+        now = int(time.time())
+        if ch:
+            self.stream.write(ch)
+            self.stream.flush()
+        elif now != self.tick:
+            self.stream.write("-/|\\"[self.count % 4] + "\b")
+            self.stream.flush()
+            self.count = self.count + 1
+            self.tick = now
+
+    def end(self, msg=None):
+        """Write the end message."""
+        if msg is None:
+            msg = self.endmsg
+        if self.stream:
+            self.stream.write("...(%2.2f sec) %s.\n"
+                              % (time.time() - self.time, msg))
 
 # End
 # vim: set expandtab shiftwidth=4
