@@ -289,6 +289,35 @@ size_t strlcpy(char *dst, const char *src, size_t siz)
 
 // End of strlcat()/strlcpy() section
 
+#ifndef HAVE_STRNLEN
+
+size_t strnlen(const char *s, size_t maxlen)
+{
+    size_t len = 0;
+    while (len < maxlen && *s++) ++len;
+    return len;
+}
+
+#endif // !HAVE_STRNLEN
+
+#ifndef HAVE_STPNCPY
+
+#include <string.h>
+
+char *stpncpy(char *dst, const char *src, size_t maxlen) {
+    const size_t srclen = strnlen(src, maxlen);
+    if (srclen < maxlen) {
+        memcpy(dst, src, srclen);
+        memset(dst + srclen, 0, maxlen - srclen);
+        return dst + srclen;
+    } else {
+        memcpy(dst, src, maxlen);
+        return dst + maxlen;
+    }
+}
+
+#endif // !HAVE_STPNCPY
+
 /*
  * Provide sincos() on platforms that don't have it.
  * Getting scons to test for sincos() and pass -Werror not possible.
